---
title: "Machine Learning"
---

# Machine Learning

Meltano will start with [scikit](https://github.com/scikit-learn/scikit-learn), as a base, and may support other ML libraries in the future.

The machine learning workflow will be built on top of the ELT workflow.

## Machine Learning toolkits

We are looking over the following toolkits to build the Meltano ML workflow:

  - [scikit](https://github.com/scikit-learn/scikit-learn)
  - [gym](https://gym.openai.com/)

> Interested in another toolkit? Please let us know.

## Training

We are looking over the following toolkits to build the training workflow:

  - [Ludwig](https://uber.github.io/ludwig/)
  - [Pachyderm](https://www.pachyderm.io/)
  
Meltano aims at making your training set versionable and re-usable.

## Validating

Meltano aims at tracking the error rate using a specific dashboard.
